function res = annular0(X0, d, A, ULS, UGS, RHOL, RHOg, VISL, VISG, beta)
% 'Calculating the force balance function value for DLD=0.5*X0
% '
% ' DLD = film thickness/diameter
% ' DELTA = film thickness (m)
% ' DG  = hydraulic diameter, gas (m)
% ' DL  = hydraulic diameter, liquid (m)
% ' Ag  = cross sectional area, gas (m2)
% ' Al  = cross sectional area, liquid (m2)
% ' Sl  = liquid circumference (m)
% ' Si  = gas/liquid interface circumference (m)
% ' UL  = liquid velocity (m/s)
% ' Ug  = gas velocity (m/s)
    DLD = 0.5 * X0;
    Delta = DLD * d;
    Dg = d - 2 * Delta;
    Ag = 3.14 / 4 * Dg ^ 2;
    AL = A - Ag;
    SL = 3.14 * d;
    SI = 3.14 * Dg;
    UL = ULS * A / AL;
    Ug = UGS * A / Ag;
    DL = 4 * AL / SL;
% '
    REL = UL * DL * RHOL / VISL;
% ' Blasius friction factor coefficients and exponent:
    if REL < 1500 
        CT = 16;
        n = 1 ;
    else
        CT = 0.046;
        n = 0.2;
    end
% ' Liquid shear stress:
    TAUL = CT * REL ^ (-n) * 0.5 * RHOL * UL ^ 2;
% ' Interfacial friction factor:
    fi = 0.005 * (1 + 300 * Delta / d);
% ' Gas/liquid interface shear stress:
    TAUi = fi * 0.5 * RHOg * abs(Ug - UL) * (Ug - UL);
% ' Force balance function value:
    g = -TAUL * SL / AL + TAUi * (SI / AL + SI / Ag) - (RHOL - RHOg) * 9.81 * sin(beta);
    res = g;
end