% '#######################################
% 'Annular_flow_filmthickness
% '#######################################
function res = annular_X_FP_old2(d, A, ULS, UGS, RHOL, RHOg, VISL, VISG, beta)
% ' Calculation of film thickness in annular flow using force balance
% ' The root of the force balance function is determined useing a modified False Position method.
% '
% 'Checking if flow is single phase
% if (ULS <= 0) && (UGS <= 0) 
%     res = 0;
%     return;
% end

    X = 0.001;
    Gr = stratified0(X, d, A, ULS, UGS, RHOL, RHOg, VISL, VISG, beta);
    
    i = 1;
    while abs(Gr) > 0.1 % Newton Raphson
        
      if i==1 % First iteration
          X_old = X;
          Gr_old = Gr;
          X = 0.999;
          Gr = stratified0(X, d, A, ULS, UGS, RHOL, RHOg, VISL, VISG, beta);  
%           if Gr * Gr_old >0 % Same signe implies that no solution exists
%               disp('No solution for Annular flow');
%               res = 5; % Error output
%               return;
%           end
      else
          temp = X;
          X = X - Gr/(Gr-Gr_old)*(X-X_old);
          X_old = temp;
          if X<0  % X is out of bounds
              X = X_old/2;
          elseif X>1
              X = (1+X_old)/2;
          end   

          Gr_old = Gr;
          Gr = stratified0(X, d, A, ULS, UGS, RHOL, RHOg, VISL, VISG, beta);  
      end     
      if i>100
          disp('Annular flow failed to converge');
          res = 5; % Error output
          return;
      end
      i = i+1;
    end
    res = X;
end