%Bubble_flow

function [DPDX, rhom, holdup] = dpdx_bubbleflow(d, ULS, UGS, US, RHOL, RHOg, VISL, VISG, SIG, beta, Uo)
%Module for testing on bubble flow regime and calculating pressure gradient
global rough


%Calculations for dispersed bubble flow:

%   Alfa = gas void fraction, no-slip
        alfa = UGS / US;
%   VISM = mixture viscosity (Pa-s)
%   RHOm = mixture density (kg/m3)
%   ED   = dimensionless pipe roughness
        VISM = VISL * (1 - alfa) + VISG * alfa;
        rhom = RHOL * (1 - alfa) + RHOg * alfa;

%   REmx = Reynolds number of mixture
        REmx = US * d * rhom / VISM;
%   Calculation of friction factor
        if (REmx > 2000) 
           Frm = frictionFactor(d, rough, REmx);
        else
           Frm = 16 / REmx;
        end

%   DBMX = critical bubble diameter
        DBMX = (0.725 + 4.15 * (alfa) ^ 0.5) * (SIG / RHOL) ^ 0.6 * (2 * Frm / d * US ^ 3) ^ (-0.4);
        COSB = cos(beta);
        if (COSB < 0.000001) 
            COSB = 0.000001;
        end
        
        
%    DCD = critical bubble size below which bubble are prevented from deformation
%    DCB = critical bubble size below which bubble migration to upper part of pipe is prevented
        DCD = 2 * (0.4 * SIG / (abs(RHOL - RHOg) * 9.81)) ^ 0.5;
        DCB = 0.375 * (RHOL / (RHOL - RHOg)) * Frm * US ^ 2 / (9.81 * COSB);
        if (DCB > DCD) 
            DCB = DCD;
        end

% Calculations for bubbly flow:

%   Uo = bubble rise velocity
        if abs(Uo) < 0.00001 
            Uo = 0.00001;
        end

        MM = Uo + UGS + ULS;
        Alfab = (MM - (MM ^ 2 - 4 * Uo * UGS) ^ 0.5) / (2 * Uo);
dispersed_bubble = false;
% Checking for dispersed bubble flow:
%   Dispersed bubble flow if critical bubble diameter < DCB and void fraction <0.52
        if (DBMX < DCB) && (alfa < 0.52) 
          dispersed_bubble = true;

%   Checking for bubbly flow:
        elseif (Alfab < 0.25) && (beta > 1.3) 
          bubbly_flow = true;
          alfa = Alfab;
          rhom = RHOL * (1 - alfa) + RHOg * alfa;
          %   REmx = Reynolds number of mixture
                 
          REmx = US * d * rhom / VISM;
%   Calculation of friction factor
            if (REmx > 2000) 
                Frm = frictionFactor(d, rough, REmx);
            else
                Frm = 16 / REmx;
            end

        else
           DPDX = 0;
           holdup = 0;
           rhom = 0;
           return;  
        end

        if (dispersed_bubble == true) || (bubbly_flow == true) 

%   Calculation of pressure gradient for bubble flow (dispersed or bubbly):

%   Recalculating mixture density using final void fraction:
            
            holdup = 1-alfa;
% %   W  = mass flow rate
% %   G  = mass flux
% %   XG = mass fraction of gas (quality)
%             W = ULS * A * RHOL + UGS * A * RHOg;
%             g = W / A;
%             XG = UGS * A * RHOg / W;
            DPDX = 2 / d * Frm * rhom * US ^ 2 + rhom * 9.81 * sin(beta);
        end
            

%   Alternative dpdx-equation including an acceleration term:
%   NOTE: Pressure, P, must be included in the function definition when using the equation below.
%        dpdx_bubbleflow = (2 / D * Frm * rhom * Us ^ 2 + rhom * 9.81 * Sin(BETA#)) / (1 - G ^ 2 * XG / (RHOg * P))

end