% '#######################################
% 'Stratified_flow_dPdx
% '#######################################

function DPDX = dpdx_stratified(d, A, ULS, RHOL, RHOg, VISG, beta, HLD, Ug)
% ' Testing for stratified flow regime and calculating pressure gradient
% '
% 'Checking if flow is bubble flow or single phase

% '   Calculations for stratified flow
    W = 2 * HLD - 1;
    acosW = acos(W);
    AL = 0.25 * d ^ 2 * (3.14 - acosW + W * (1 - (W) ^ 2) ^ 0.5);
    Ag = A - AL;
    SL = d * (3.14 - acosW);
    Sg = 3.14 * d - SL;
    SI = d * (1 - W ^ 2) ^ 0.5;
    UL = ULS * A / AL;
% ' Calculation of Kelvin Helmholtz instability criterion.
% ' Flow is stabilised when gravity dominates
    UgU = (1 - HLD) * (abs(RHOL - RHOg) * 9.81 * cos(beta) * Ag / (RHOg * SI)) ^ 0.5;
% '
% ' Checking for stratified flow
    if (UgU > Ug) && (beta > -1.5) && (beta < 0.5) 
% '    Calculate pressure gradient for stratified flow:
        Dg = 4 * Ag / (Sg + SI);
        Reg = Ug * Dg * RHOg / VISG;
        if Reg < 1500 
            CG = 16;
            ng = 1 ;
        else
            CG = 0.046;
            ng = 0.2;
        end
        TAUg = 0.5 * RHOg * Ug ^ 2 * CG * Reg ^ (-ng);
        TAUi = 0.5 * RHOg * abs(Ug - UL) * (Ug - UL) * CG * Reg ^ (-ng);
       DPDX = TAUg * Sg / Ag + TAUi * SI / Ag + RHOg * 9.81 * sin(beta);
    else
        DPDX = 0;
    end

end