function res = slug_annular1(X1, d, A, ULS, UGS, RHOL, RHOg, VISL, beta, UT, Ub, AlfaS)
% 'Calculating the force balance function value for DLD=0.5*X1
% 'See function slug_annular0 for definition of variables
% '
    DLD = 0.5 * X1;
    Delta = DLD * d;
    Dgf = d - 2 * Delta;
    Agf = 3.14 / 4 * Dgf ^ 2;
    ALf = A - Agf;
    SLF = 3.14 * d;
    SI = 3.14 * Dgf;
    Rf = ALf / A;
    Rsi = 1 - AlfaS;
    UL = (ULS + UGS - Ub * AlfaS) / Rsi;
    UF = (UT * Rf - (UT - UL) * Rsi) / Rf;
    Ug = (ULS + UGS - UF * Rf) / (1 - Rf);
    DLF = 4 * ALf / SLF;
    RelF = abs(UF) * DLF * RHOL / VISL;
% '   Blasius friction factor coefficients and exponent:
       if RelF < 1500 
           CT = 16;
           n = 1 ;
       else
           CT = 0.046;
           n = 0.2;
       end
    TAUL = CT * RelF ^ (-n) * 0.5 * RHOL * abs(UF) * UF;
    fi = 0.005 * (1 + 300 * Delta / d);
    TAUi = fi * 0.5 * RHOg * abs(Ug - UF) * (Ug - UF);
    g = -TAUL * SLF / ALf + TAUi * (SI / ALf + SI / Agf) - (RHOL - RHOg) * 9.81 * sin(beta);
    res = g;
end