% '#######################################
% 'Slug_filmthickness_annular
% '#######################################
function res = slug_annular_X_FP(d, A, ULS, UGS, RHOL, RHOg, VISL, beta, UT, Ub, AlfaS)
% 'Calculation of film thickness in slug film zone, modelled as annular flow
% 'The film thickness is calculated by finding the root of the force balance function
% 'The root is located using a modified False Position method
% '
% 'Checking if flow is single phase

% 'Checking for slug flow : If no other flow regimes has been identified, slug flow is assumed

    
        X0 = 0.001;
        X1 = 0.99;
        G0 = slug_annular1(X0, d, A, ULS, UGS, RHOL, RHOg, VISL, beta, UT, Ub, AlfaS);
        G1 = slug_annular1(X1, d, A, ULS, UGS, RHOL, RHOg, VISL, beta, UT, Ub, AlfaS);
        Test = G0 * G1;
        if (Test > 0) 
            X1 = 0.7;
            G1 = slug_annular1(X1, d, A, ULS, UGS, RHOL, RHOg, VISL, beta, UT, Ub, AlfaS);
        end
        I0 = 0;
        I1 = 0;
        i = 0;
        Gr = 1;
        while i < 100 && abs(Gr) > 0.01
            Xr = X1 - G1 * (X0 - X1) / (G0 - G1);
            Gr = slug_annular1(Xr, d, A, ULS, UGS, RHOL, RHOg, VISL, beta, UT, Ub, AlfaS);
            Test = G0 * Gr;
            if (Test < 0) 
                X1 = Xr;
                G1 = Gr;
                I0 = I0 + 1;
                if (I0 > 2) 
                    G0 = G0 / 2;
                end
            elseif (Test > 0) 
                X0 = Xr;
                G0 = Gr;
                I1 = I1 + 1;
                if (I1 > 2) 
                    G1 = G1 / 2;
                end
            end
            i = i + 1;
        end
        
        if i>=100
            disp('Slug annular switching to NR');
                X = 0.001;
    Gr = slug_annular1(X, d, A, ULS, UGS, RHOL, RHOg, VISL, beta, UT, Ub, AlfaS);
    
    i = 1;
    while abs(Gr) > 0.1 % Newton Raphson
        
      if i==1 % First iteration
          X_old = X;
          Gr_old = Gr;
          X = 0.999;
          Gr = slug_annular1(X, d, A, ULS, UGS, RHOL, RHOg, VISL, beta, UT, Ub, AlfaS); 
%           if Gr * Gr_old >0 % Same signe implies that no solution exists
%               disp('No solution for Slug Annular flow');
%               res = 5; % Error output
%               return;
%           end
      else
          temp = X;
          X = X - Gr/(Gr-Gr_old)*(X-X_old);
          X_old = temp;
          if X<0  % X is out of bounds
              X = X_old/2;
          elseif X>1
              X = (1+X_old)/2;
          end   

          Gr_old = Gr;
          Gr = slug_annular1(X, d, A, ULS, UGS, RHOL, RHOg, VISL, beta, UT, Ub, AlfaS);
      end     
      if i>100
          disp('Slug Annular HLD failed to converge');
          res = 5; % Error output
          return;
      end
      i = i+1;
    end
    res = X;

        else
        res = Xr;
        end


end