% '#######################################
% 'Slug_filmthickness_annular
% '#######################################
function res = slug_annular_X_FP_old2(d, A, ULS, UGS, RHOL, RHOg, VISL, beta, UT, Ub, AlfaS)
% 'Calculation of film thickness in slug film zone, modelled as annular flow
% 'The film thickness is calculated by finding the root of the force balance function
% 'The root is located using a modified False Position method
% '
% 'Checking if flow is single phase


    
    X = 0.001;
    Gr = slug_annular1(X, d, A, ULS, UGS, RHOL, RHOg, VISL, beta, UT, Ub, AlfaS);
    
    i = 1;
    while abs(Gr) > 0.1 % Newton Raphson
        
      if i==1 % First iteration
          X_old = X;
          Gr_old = Gr;
          X = 0.999;
          Gr = slug_annular1(X, d, A, ULS, UGS, RHOL, RHOg, VISL, beta, UT, Ub, AlfaS); 
%           if Gr * Gr_old >0 % Same signe implies that no solution exists
%               disp('No solution for Slug Annular flow');
%               res = 5; % Error output
%               return;
%           end
      else
          temp = X;
          X = X - Gr/(Gr-Gr_old)*(X-X_old);
          X_old = temp;
          if X<0  % X is out of bounds
              X = X_old/2;
          elseif X>1
              X = (1+X_old)/2;
          end   

          Gr_old = Gr;
          Gr = slug_annular1(X, d, A, ULS, UGS, RHOL, RHOg, VISL, beta, UT, Ub, AlfaS);
      end     
      if i>100
          disp('Slug Annular HLD failed to converge');
          res = 5; % Error output
          return;
      end
      i = i+1;
    end
    res = X;


end