% '#######################################
% 'Slug_liquidlevel_stratified
% '#######################################
function res = slug_stratified_HLD_old2(d, A, US, RHOL, RHOg, VISL, VISG, beta, UT, Rsi, UL)
% 'Calculation of liquid level in slug film zone, modelled as stratified flow
% 'The liquid level is calculated by finding the root of the force balance function
% 'The root is located using a modified False Position method
% '

% 'Checking for slug flow : If no other flow regimes has been identified, slug flow is assumed
% '    If (dpdx_bubble = "NA") And (dpdx_strat = "NA") And (dpdx_ann = "NA") Then
% '
% ' Calculating slug parameters which are independent of liquid level, HLD:
% '
% '   Slug Reynolds number:
%       Res = US * RHOL * d / VISL;
% % '
% % '   CONSTANTS FOR CALCULATING FRICTION FACTOR:
%       CS = 0.046;
%       n = 0.2;
% 
%         Fs = CS * (Res) ^ (-n);
% '
    X = 0.001;
    Gr = slug_stratified0(X, d, A, RHOL, RHOg, VISL, VISG, beta, US, UT, UL, Rsi); 
    
    i = 1;
    while abs(Gr) > 0.1 % Newton Raphson
        
      if i==1 % First iteration
          X_old = X;
          Gr_old = Gr;
          X = 0.999;
          Gr = slug_stratified0(X, d, A, RHOL, RHOg, VISL, VISG, beta, US, UT, UL, Rsi);  
%           if Gr * Gr_old >0 % Same signe implies that no solution exists
%               disp('No solution for Slug Stratified flow');
%               res = 5; % Error output
%               return;
%           end
      else
          temp = X;
          X = X - Gr/(Gr-Gr_old)*(X-X_old);
          X_old = temp;
          if X<0  % X is out of bounds
              X = X_old/2;
          elseif X>1
              X = (1+X_old)/2;
          end   

          Gr_old = Gr;
          Gr = slug_stratified0(X, d, A, RHOL, RHOg, VISL, VISG, beta, US, UT, UL, Rsi);  
      end     
      if i>100
          disp('Slug Stratified HLD failed to converge');
          res = 5; % Error output
          return;
      end
      i = i+1;
    end
    res = X;
end