function res = stratified1(X1, d, A, ULS, UGS, RHOL, RHOg, VISL, VISG, beta)
% Calculation of force balance function value for HLD=X1
% See function stratified0 for definition of variables

    HLD = X1;
    W = 2 * HLD - 1;
    acosW = acos(W);
    AL = 0.25 * d ^ 2 * (3.14 - acosW + W * (1 - W ^ 2) ^ 0.5);
    Ag = A - AL;
    SL = d * (3.14 - acosW);
    Sg = 3.14 * d - SL;
    SI = d * (1 - W ^ 2) ^ 0.5;
    DL = 4 * AL / SL;
    Dg = 4 * Ag / (Sg + SI);
    UL = ULS * A / AL;
    Ug = UGS * A / Ag;
   % alfa = Ag / (AL + Ag);
    REL = UL * DL * RHOL / VISL;
    Reg = Ug * Dg * RHOg / VISG;
    if REL < 1500 
        Cl = 16;
        nL = 1 ;
    else
        Cl = 0.046;
        nL = 0.2;
    end
    if Reg < 1500 
        CG = 16;
        ng = 1 ;
    else
        CG = 0.046;
        ng = 0.2;
    end
    TAUL = 0.5 * RHOL * UL ^ 2 * Cl * REL ^ (-nL);
    TAUg = 0.5 * RHOg * Ug ^ 2 * CG * Reg ^ (-ng);
    TAUi = 0.5 * RHOg * abs(Ug - UL) * (Ug - UL) * CG * Reg ^ (-ng);

    res = TAUg * Sg / Ag - TAUL * SL / AL + TAUi * SI * (1 / AL + 1 / Ag) - (RHOL - RHOg) * 9.81 * sin(beta);
end