function [pTubing, pPLEM_WH, pRiser_Flow, p, qo_sc_res, qg_sc, qw_sc, qgl_sc_res, dp_choke] = GL_parallel_NR(qo_sc, qw_sc, qg_sc, pR)

global TR pSep pBP_0 h_tubing l_tubing h_flowline l_flowline h_riser l_riser ...
        nWells bara day wc GOR_0 l_PLEM_WH h_PLEM_WH ...
        nManifold wells_in_manifold step_length qgl_sc_max ID_t ID_f ID_m
  qo_sc_init = qo_sc;  
[pWf] = IPR_multi(qo_sc, pBP_0, pR);
qw_sc = qo_sc.*wc; 
qg_sc = qo_sc.*GOR_0; 
fprintf('dp_choke [bar]: \n\n');
step_length = 10; % [m]

%% Pressure drop in tubing, from Bottom of Well to WH.
n_steps_t = zeros(1, nWells);
for j = 1:nWells
    n_steps_t(j) = l_tubing(j)/step_length;   % For tubing
    pTubing = zeros(n_steps_t(j)+1, nWells);
end



qgl_sc = zeros(1, nWells);
dp_choke = zeros(1, nWells);
epsilon = 100;
increased_init_gl = [];
first_iteration = true;
real_dp_choke = true;
dp_choke_mat = zeros (nWells);
active_wells = 1: nWells;                      
re_original_rate = false;
    endless_loop = false;
for i = 1:nWells
    reduced_rate (i) = false;
    inactive_wells (i) = false;
    factor(i) = 1;
    original_rate (i) = false;

end

while epsilon > 0.1
    
for z = [active_wells, nWells+1]    
    
    
for j = 1:nWells    
    
    
    theta = asind(h_tubing(j)/l_tubing(j));   % Inclination in degrees from horizontal.
    pTubing (1, j) = pWf(j);
    T = TR;  % Should be made into a function.
    
        if pTubing(1, j)<pSep
  %          pTubing(:, j) = real(pTubing(:, j));  % If pTubing goes below zero, imaginary numbers will be generated.
            endless_loop = true;
            endless_loop_well = j;
            break;
        end
    

    for i = 1:n_steps_t(j)    
        

         
         
         [ql, qg, dens_l, dens_g, visc_l, visc_g] = local_properties(pTubing(i, j), T, qo_sc(j), qw_sc(j), qg_sc(j), qgl_sc(j)); % Local fluid rates and properties 

         dpds = dpBeggs_Brill(ql, qg, dens_l, dens_g, visc_l, visc_g, theta, step_length, ID_t);   % [Pa]
        
         pTubing(i+1, j) = pTubing(i, j) - dpds/bara;
         
        if sum( imag(pTubing(:, j)) )~=0 || pTubing(i+1, j)<pSep||isnan(pTubing(i+1, j))
            pTubing(:, j) = real(pTubing(:, j));  % If pTubing goes below zero, imaginary numbers will be generated.
            endless_loop = true;
            endless_loop_well = j;
            break;
        end
         
         
    end
   
    if reduce_init_rate
        break;
    end
    

    
end

% Find final nonzero element in tubing (pWh)
if  endless_loop == false;
for i = 1:nWells
    if pTubing(end, i)==0
        X = find (pTubing(:, i) == 0);
        pTubing_end(i) = pTubing( X(1)-1, i);
    else
        pTubing_end(i) = pTubing(end, i);
    end
    
    
end





%% Pressure drop in riser and flowline, from Sep to PLEM.
n_steps_f = (l_riser+l_flowline)/step_length;

pRiser_Flow = zeros(n_steps_f+1, 1);
pRiser_Flow (end) = pSep;
T = TR;  % Should be made into a function.

for i = (n_steps_f):-1:1
    
    
    
    [ql, qg, dens_l, dens_g, visc_l, visc_g] = local_properties(pRiser_Flow(i+1), T, sum(qo_sc), sum(qw_sc), sum(qg_sc), sum(qgl_sc)); % Local fluid rates and properties 

    if i<=l_flowline/step_length  % I.e. is the calculation in the flowline or in the riser
        theta = asind(h_flowline/l_flowline);
    else
        theta = asind(h_riser/l_riser);
    end    
    dpds = dpBeggs_Brill(ql, qg, dens_l, dens_g, visc_l, visc_g, theta, step_length, ID_f);   % [Pa]
        
    pRiser_Flow(i) = pRiser_Flow(i+1) + dpds/bara;
end


n_steps_m = zeros(1, nManifold);  % Steps from PLEM to Manifold
for j = 1:nManifold
    n_steps_m(j) = l_PLEM_WH(j)/step_length;   % For tubing
end
pPLEM_WH = zeros(  max(n_steps_m)+1, nManifold);
pPLEM_WH(end, :) = pRiser_Flow(1, :);

for r = 1:nManifold     % "r" is a new variabel so not to disturb "j" from the tubing-section.
    
    % To keep track of which wells are calculated:
    temp_10=0;
    for y = 1:r
        temp_9 = temp_10;
        temp_10 = temp_10+wells_in_manifold(y);
    end
    
    for i = ( max(n_steps_m) ):-1: ( max(n_steps_m) - n_steps_m(r)+1   )
        

        
        
        [ql, qg, dens_l, dens_g, visc_l, visc_g] = local_properties(pPLEM_WH(i+1, r), T, sum(qo_sc(temp_9+1:temp_10)), sum(qw_sc(temp_9+1:temp_10)), sum(qg_sc(temp_9+1:temp_10)), sum(qgl_sc(temp_9+1:temp_10))); % Local fluid rates and properties 
        
        theta = asind(h_PLEM_WH(r)/l_PLEM_WH(r));
    
        dpds = dpBeggs_Brill(ql, qg, dens_l, dens_g, visc_l, visc_g, theta, step_length, ID_m(r));   % [Pa]
        
        pPLEM_WH(i, r) = pPLEM_WH(i+1, r) + dpds/bara;
    end
    
end

for i = 1:nManifold
    if pPLEM_WH(1, i)==0
        X = find (pPLEM_WH(:, i) == 0);
        pPLEM_WH_end(1, i) = pPLEM_WH( X(end)+1, i);
    else
        pPLEM_WH_end(1, i) = pPLEM_WH(1, i);
    end 
end

for i = 1:nManifold
    temp_10=0;
    for y = 1:i
        temp_9 = temp_10;
        temp_10 = temp_10+wells_in_manifold(y);
    end
    
    dp_choke(1, temp_9+1:temp_10) = pTubing_end (1, temp_9+1:temp_10) - pPLEM_WH_end(1, i);
end
end
if z<=nWells
%         if (min(dp_choke(active_wells))<-25)
%             min_temp = find(dp_choke <= min(dp_choke)+0.1);
%             if abs(sum(abs(dp_choke(active_wells)))+sum(dp_choke(min_temp)))<(1*nWells/9)  % Proper scaling term?
%                 endless_loop = true;
%             end
%         end
    if isnan(sum(dp_choke)) || endless_loop % Imaginary numbers due to high oil rate
         endless_loop = false;
%         if first_iteration
%             qo_sc_init = qo_sc;
%         end
        if qgl_sc(endless_loop_well)==0
            %qgl_sc(endless_loop_well)=qgl_sc_max*0.95;
            increased_init_gl = [increased_init_gl, endless_loop_well];
        else
            qo_sc_init(endless_loop_well) = qo_sc_init(endless_loop_well)*0.9;
        end
        qgl_sc(:) = 0;
        qgl_sc(increased_init_gl) = qgl_sc_max*0.95;
        qo_sc = qo_sc_init;
        
        
 
        [pWf] = IPR_multi(qo_sc, pBP_0, pR);
        qw_sc = qo_sc.*wc; 
        qg_sc = qo_sc.*GOR_0; 
        %qgl_sc = zeros(1, nWells);
        active_wells = 1:nWells;
        %fprintf('Error: Too high rates in some of the wells result in NaN dp_choke or an endless loop. All rates reduced by 1%%. \n');
        first_iteration = true;
        real_dp_choke = false;
        break;
    else
        dp_choke_mat(z, :) = dp_choke;
    end
else
   % disp(dp_choke);
end


if first_iteration
    re_original_rate = false;
    qo_sc_old = qo_sc; % = Initial rates
    qo_sc_init = qo_sc;
    qgl_sc_old = qgl_sc; % = 0
    if dp_choke>0
        break;  % I.e. all elements are positive.
    elseif dp_choke<0  % I.e. all elements are negative.
       % delta = ones(1, nWells)*qgl_sc_max;
        for i =1:nWells
            if qgl_sc_old(i)>0
                delta(i)=qgl_sc_max*0.05;
            else
                delta(i) = qgl_sc_max;
            end
            reduced_rate(i) = false;
            inactive_wells (i) = false;
            factor(i) = 1;
            original_rate (i) = false;
        end
    else % Some elements are negative, some positive.
        active_wells = [];
        for i = 1:nWells
            reduced_rate(i) = false;
            inactive_wells (i) = false;
            factor(i) = 1;
            original_rate (i) = false;
            if dp_choke(i)>0
                delta(i) = 0;
                inactive_wells (i) = true;
            else
                active_wells = [active_wells i];
                if qgl_sc_old(i)>0
                    delta(i)=qgl_sc_max*0.05;
                else
                    delta(i) = qgl_sc_max;
                end
            end
        end
    end    
    qgl_sc(active_wells(1)) = delta(active_wells(1));
    dp_choke_old = dp_choke;
    first_iteration = false;    
    break;
else
    
    if z<max(active_wells)
        qgl_sc = qgl_sc_old;
        qo_sc = qo_sc_old;
        temp = find(active_wells(:) == z); % Finds the active well placement in "active_wells".
        if reduced_rate(active_wells(temp+1))
            qo_sc(active_wells(temp+1)) = qo_sc_old(active_wells(temp+1))+delta(active_wells(temp+1));
        else
            qgl_sc(active_wells(temp+1)) = qgl_sc_old(active_wells(temp+1))+delta(active_wells(temp+1));
        end
        
        for i = active_wells    
            [pWf] = IPR_multi(qo_sc, pBP_0, pR);
            qw_sc(i) = qo_sc(i).*wc(i);
            qg_sc(i) = qo_sc(i).*GOR_0;
        end
        
        
        
    elseif z==max(active_wells)

        for i = active_wells
            if reduced_rate(i)
                qo_sc(i) = qo_sc_old(i) + delta(i);
            else
                qgl_sc(i) = qgl_sc_old(i) + delta(i);
            end
        end

        for i = active_wells
            [pWf] = IPR_multi(qo_sc, pBP_0, pR);
            qw_sc(i) = qo_sc(i).*wc(i);
            qg_sc(i) = qo_sc(i).*GOR_0;
        end
        
        
    else
    % Create the Jacobian:

    if (abs(dp_choke(active_wells))<0.1) % Ending criteria
        if (dp_choke(1, :)+0.1>0)
            if real_dp_choke
                first_iteration = true;
                real_dp_choke = true;
                break;
            end
        end
    end
    
    Jacobian = zeros(length(active_wells));
    count_i = 0;
    count_j = 0;
    for i = active_wells
        count_i = count_i+1;
       for j = active_wells
           count_j = count_j+1;
           Jacobian (count_i, count_j) = (dp_choke_mat(j, i)-dp_choke_old(i))/delta(j);
       end
        count_j = 0;
    end

    % Calculate the new GL and oil -rates:
    qgl_sc_old = qgl_sc;
    qo_sc_old = qo_sc;
    qgl_sc = qgl_sc';
    qo_sc = qo_sc';
    
    
    dp_choke = dp_choke';
    now_active = [];
    dp_choke_active = [];
    
    for i = active_wells       
        if reduced_rate(i)
            now_active = [now_active; qo_sc(i)];
        else
            now_active = [now_active; qgl_sc(i)];
        end
        dp_choke_active = [dp_choke_active; dp_choke(i)]; 
    end
    next_active = now_active - inv(Jacobian)*dp_choke_active; 
    
    count = 0;
    for i = active_wells 
        count = count+1;
        if reduced_rate(i)
%             if next_active(count)>qo_sc_min
                qo_sc(i) = next_active(count);
%             else
%                 qo_sc(i) = qo_sc(count)*0.9;
%             end
        else
            qgl_sc(i) = next_active(count);
        end
    end
    
    for i = active_wells 
        if qgl_sc(i)<0 && dp_choke(i)<0  % This may happen for systems with very large rates. If the previous dp_choke was negative, then the new GL-rate should be positive.
            qgl_sc(i) = -qgl_sc(i);
        end
    end

    temp = active_wells;
    active_wells = [];
    for i = temp % Deactivate wells
        if qgl_sc(i)<=0  % Set this rate equal to zero, and exclude the well from further calculations.
            qgl_sc(i) = 0;
            qo_sc(i) = qo_sc_init(i);
            qgl_sc_old(i) = 0;
            inactive_wells(i) = true;
         else
             active_wells = [active_wells i];
        end
    end
    qgl_sc = qgl_sc';
    qo_sc = qo_sc';
    
    active_wells =  [];
    for i=1:nWells
        if inactive_wells(i) && dp_choke(i)<0  % Re-activate the well
            qgl_sc(i) = qgl_sc_max;
            qo_sc(i) = qo_sc_init(i);
            active_wells = [active_wells i];
            inactive_wells(i) = false;
        elseif inactive_wells(i)==false 
            active_wells = [active_wells i];
        end
    end
    if re_original_rate  % Well started with original (not reduced) oil rate.
        for i = active_wells
            if original_rate(i)
                qgl_sc(i) = qgl_sc_max*0.5;
%                 qo_sc(i) = qo_sc_init(i);
                original_rate(i) = false;
%                 reduced_rate(i) = false;
            end
        end
        re_original_rate = false;
    end
            
    
    for i = active_wells
        if qgl_sc(i) > qgl_sc_max
            qgl_sc(i) = qgl_sc_max;
            if qgl_sc_old(i) ==qgl_sc_max
                delta(i) = qo_sc(i)*0.9-qo_sc(i);
                qo_sc(i) = qo_sc(i)*0.9;
                reduced_rate(i) = true;
            else
                delta(i) = qgl_sc(i) - qgl_sc_old(i);
                
            end
        else

            if reduced_rate(i)
                % (Below) Should not be qo_sc(i)<qo_sc_old(i) because then
                % it's impossible for the solver to recalculate within the
                % correct interval. 
                
                if qo_sc(i)<qo_sc_init(i)*(0.9^factor(i))  % The rate should be within initial or minimum rates.
                      factor (i) = factor(i)+1;

                        qo_sc(i) = qo_sc_init(i)*(0.9^factor(i));
                elseif qo_sc(i)>qo_sc_init(i) % The solver is searching for GL<GL_max
                        qo_sc(i) = qo_sc_init(i);
                        reduced_rate(i) = false;
                        original_rate (i) = true;
                        re_original_rate = true;
                end
                delta(i) = qo_sc(i) - qo_sc_old(i);
            else
                delta(i) = qgl_sc(i) - qgl_sc_old(i);
            end
            
        end
    end
    
    qo_sc = qo_sc_old;  % Starting conditions for next iteration:
    qgl_sc = qgl_sc_old;
    if reduced_rate(active_wells(1))
        qo_sc(active_wells(1)) = qo_sc(active_wells(1)) + delta(active_wells(1));
    else
        qgl_sc(active_wells(1)) = qgl_sc(active_wells(1)) + delta(active_wells(1));
    end

    
        for i = active_wells
            [pWf] = IPR_multi(qo_sc, pBP_0, pR);
            qw_sc(i) = qo_sc(i).*wc(i);
            qg_sc(i) = qo_sc(i).*GOR_0;
        end

    
    dp_choke = dp_choke';
    dp_choke_old = dp_choke;
    



    


    disp(dp_choke);
    Jacobian = [];
    end
end


end

if first_iteration && real_dp_choke   % I.e. first dp_choke>0;
    break;
end
real_dp_choke = true;

end





disp(dp_choke);












%% Tidy-up section

% Pressures in the pipes:
p = zeros( (length(pTubing(:, 1))+length(pPLEM_WH(:, 1))+length(pRiser_Flow(:, 1)))-1, nWells);
p(1:length(pTubing), :) = pTubing;

for i = 1:nManifold
    temp_10=0;
    for y = 1:i
        temp_9 = temp_10;
        temp_10 = temp_10+wells_in_manifold(y);
    end
    for a = temp_9+1:temp_10
        p( (length(pTubing(:, 1))+1):(length(pTubing(:, 1))+length(pPLEM_WH(:, 1))) , a) = pPLEM_WH(:, i);
    end
    
end

for j =1:nWells
p ( (length(pTubing(:, 1))+length(pPLEM_WH(:, 1))):(length(pTubing(:, 1))+length(pPLEM_WH(:, 1))+length(pRiser_Flow(:, 1)))-1, j) = pRiser_Flow;
end

% GL rates:
for j =1:nWells
    temp = find(qgl_sc(:, j) ~= 0);
    if isempty(temp)
        qgl_sc_res(1, j) = 0;
    else
        qgl_sc_res(1, j) = qgl_sc(temp(end), j);
    end
end
qgl_sc_res = qgl_sc_res*day;

% Oil rates:
size_oil = size(qo_sc);
if size_oil(1)>1 % I.e. at least one well is calculated with reduced oil rate.
    qo_sc_res = zeros(1, nWells);
    for k = 1:nWells
        nonzero_value = find(qo_sc(:, k) ~=0);
        correct_value = nonzero_value(end);
        qo_sc_res(k) = qo_sc(correct_value, k)*day;
    end
else
    qo_sc_res = qo_sc*day;   % I.e. Original oil rates count.
end

fprintf('Calculated oil rates [Sm3/D]: \n\n');
format short g;
disp(qo_sc_res);
fprintf('Calculated GL rates [Sm3/D]: \n\n');
disp(qgl_sc_res);

end