function [pTubing, pPLEM_WH, pRiser_Flow, p, qo_sc_res, qg_sc, qw_sc, qgl_sc_res, dp_choke] = GL_sequential_spline(qo_sc, qw_sc, qg_sc, pR)

global TR pSep pBP_0 h_tubing l_tubing h_flowline l_flowline h_riser l_riser ...
        nWells bara day qgl_sc_max wc GOR_0 qo_sc_min l_PLEM_WH h_PLEM_WH ...
        nManifold wells_in_manifold step_length
    

pWf = IPR_multi(qo_sc, pBP_0, pR);

if pWf>0  % Do nothing
else % i.e. At least one element is negative.
    fprintf('Some of the rates are initially too high (resulting in negative pWf) and are reduced. \n \n');
    while qo_sc>0
        temp = find(pWf<0);   % Find the negative elements
        qo_sc (temp) = qo_sc(temp)*0.8;  % Reduce the rate of those wells with 20%
        pWf = IPR_multi(qo_sc, pBP_0, pR);
        if pWf>0  % The rate is now "ok".
            break;  % Out of the while loop
        end
    end
    qw_sc = qo_sc.*wc; 
    qg_sc = qo_sc.*GOR_0; 
end
fprintf('dp_choke [bar]: \n\n');

step_length = 10; % [m]

%% Pressure drop in tubing, from Bottom of Well to WH.
n_steps_t = zeros(1, nWells);
for j = 1:nWells
    n_steps_t(j) = l_tubing(j)/step_length;   % For tubing
    pTubing = zeros(n_steps_t(j)+1, nWells);
end



qgl_sc = zeros(1, nWells);
count_1 = 1; %Initiated for GL. Number counting the points used in interpolation to find GL-rate.
count_2 = 0;
count_3 = 1;
count_4 = 0;
count_5 = 0;
adjust = 0;
position_s = 0;
position_count1 = 0;
pPLEM_WH_end = zeros(1, nManifold);
dp_choke = zeros(1, nWells);
deltaP =0;
reduced_oil_rate = false;
optimal_oil_rate = false;
s = 0;
str = 'ape';
while s>=0 || count_1 ==1
    if s ==0
        temp1 = 1;
        temp2 = 2;
    else
        temp1=s;
        temp2 = count_1;
    end
while (abs(deltaP (temp2-1, temp1)) > 0.1) || (count_1==1)
for j = 1:nWells    
    
    if s>0
        j = s;
        if count_1 == 2 && optimal_oil_rate==false
            if count_2<nWells
            qgl_sc(count_1, j) = qgl_sc_max;
            count_4 = 0;
            else
                qgl_sc(1, j) = qgl_sc(end, j);
                qgl_sc(count_1, j) = qgl_sc_max;
                qgl_sc((count_1+1):end, j) = 0; % If a well is re-calculated with GL, thise values need to be zero.
                deltaP(2:end, j) = 0;
            end
        elseif deltaP(2, j)<0 && optimal_oil_rate==false   % I.e. deltaP(q_gl_max) is too low/below zero.
            count_1 = 2;
            if count_4<3
                count_4 = count_4 + 1;  % Try first with reduced GL-rates.
                qgl_sc(count_1, j) = qgl_sc(count_1, j)*0.65;
            else
                
                    count_1 = 1;
                    deltaP (:, j) = 0;
                    %qgl_sc(count_1, j) = 0; Not necessary. It's already 0.
                    qo_sc(1, j) = qo_sc(1, j)*0.9; % This re-calculates the first deltaP for no GL and lower oil rate.
                    qw_sc(j) = qo_sc(1, j).*wc(j);
                    qg_sc(j) = qo_sc(1, j).*GOR_0;
                    pWf(j) = IPR_multi(qo_sc(1, j), pBP_0, pR);

                if qo_sc(1, j)< qo_sc_min || pWf(j)<pSep
                    fprintf('Error: pR is too low for well %d to be produced. Remove this well from the network. \n', j);
                    return;
                end

                    reduced_oil_rate = true;
                
            end
            
            
        else
            
            if reduced_oil_rate  % Solver have found a reduced oil rate that gives positive deltaP
                count_3 = count_3 + 1;
                if count_3 == 2  % First iteration.
                    count_1 = 2;
                    % qgl_sc is kept the same
                    deltaP(1, j) = deltaP(2, j);
                    deltaP(2:end, j) = 0;
                    qo_sc(count_3, j) = qo_sc(count_3-1, j)/0.9;
                    
                    optimal_oil_rate = true;
                else
                    
                    if abs(deltaP(count_3-1, j)-deltaP(count_3-2, j))<0.00001
                        count_5 = count_5+1;
                        adjust = count_5/10;
                        if adjust>=1
                            fprintf('Spline can''t manage to find the optimal oil rate for well %d.\n', j);
                            count_3 = 3;
                             qo_sc(3, j) = qo_sc(1, j);
                             qo_sc(4:end, j) = 0;
                             deltaP(count_3:end, j) = 0;
                             qw_sc(j) = qo_sc(count_3, j).*wc(j);
                             qg_sc(j) = qo_sc(count_3, j).*GOR_0;
                             pWf(j) = IPR_multi(qo_sc(count_3, j), pBP_0, pR);
                            % break;
                        else
                            qo_sc(count_3, j)=(qo_sc(1, j)+qo_sc(2, j))*adjust;
                            qw_sc(j) = qo_sc(count_3, j).*wc(j);
                            qg_sc(j) = qo_sc(count_3, j).*GOR_0;
                            pWf(j) = IPR_multi(qo_sc(count_3, j), pBP_0, pR);
                        end
                        
                    else
                    qo_sc(count_3, j) = spline(deltaP(1:count_3-1, j), qo_sc(1:count_3-1, j), 0); % This re-calculates the first deltaP for no GL and lower oil rate.
                    qw_sc(j) = qo_sc(count_3, j).*wc(j);
                    qg_sc(j) = qo_sc(count_3, j).*GOR_0;
                    pWf(j) = IPR_multi(qo_sc(count_3, j), pBP_0, pR);
                    end
                end
                
            else
            
            qgl_sc(count_1, j) = spline(deltaP(1:count_1-1, j), qgl_sc(1:count_1-1, j), 0);
            end
            if qgl_sc(count_1, j) >qgl_sc_max
                qgl_sc(count_1, j) = qgl_sc(count_1-1, j)*0.5;
            end
        end
    end
    
    theta = asind(h_tubing(j)/l_tubing(j));   % Inclination in degrees from horizontal.
    pTubing (1, j) = pWf(j);
    T = TR;  % Should be made into a function.
    
    
    

    for i = 1:n_steps_t(j)    
        
        
         
         
         [ql, qg, dens_l, dens_g, visc_l, visc_g] = local_properties(pTubing(i, j), T, qo_sc(count_3, j), qw_sc(j), qg_sc(j), qgl_sc(count_1, j)); % Local fluid rates and properties 

         dpds = dpBeggs_Brill(ql, qg, dens_l, dens_g, visc_l, visc_g, theta, step_length);   % [Pa]
        
         pTubing(i+1, j) = pTubing(i, j) - dpds/bara;
    end
   
    if sum( imag(pTubing(:, j)) )>0
        pTubing(:, j) = real(pTubing(:, j));  % If pTubing goes below zero, imaginary numbers will be generated.
    end
    
   if s>0  % Only calculate lowest well.
       break;
   end
    
end

% Find final nonzero element in tubing (pWh)
for i = 1:nWells
    if pTubing(end, i)==0
        X = find (pTubing(:, i) == 0);
        pTubing_end(i) = pTubing( X(1)-1, i);
    else
        pTubing_end(i) = pTubing(end, i);
    end
    
    
end





%% Pressure drop in riser and flowline, from Sep to PLEM.
n_steps_f = (l_riser+l_flowline)/step_length;

pRiser_Flow = zeros(n_steps_f+1, 1);
pRiser_Flow (end) = pSep;
T = TR;  % Should be made into a function.

for i = (n_steps_f):-1:1
    
    if count_2>0 % I.e. there has already been calculated at least one well with GL, and another is in progress.
        sum_gl_sc = 0;
        for k = 1:count_2
            sum_gl_sc = sum_gl_sc + qgl_sc(position_count1(count_2)  , position_s(count_2) ) + qgl_sc(count_1, s);
        end
    else
        sum_gl_sc = sum(qgl_sc(count_1, :));   % I.e. sum of GL rate for all wells in that row. Only GL in max one well.
    end
    size_oil = size(qo_sc);
    if size_oil(1)>1 % I.e. at least one well is calculated with reduced oil rate.
        sum_qo_sc = 0;
        for k = 1:nWells
            nonzero_value = find(qo_sc(:, k) ~=0);
            correct_value = nonzero_value(end);
            sum_qo_sc = sum_qo_sc + qo_sc(correct_value, k);
        end
    else
        sum_qo_sc = sum(qo_sc);   % I.e. Original oil rates count.
    end
    
    
    [ql, qg, dens_l, dens_g, visc_l, visc_g] = local_properties(pRiser_Flow(i+1), T, sum_qo_sc, sum(qw_sc), sum(qg_sc), sum_gl_sc); % Local fluid rates and properties 

    if i<=l_flowline/step_length  % I.e. is the calculation in the flowline or in the riser
        theta = asind(h_flowline/l_flowline);
    else
        theta = asind(h_riser/l_riser);
    end    
    dpds = dpBeggs_Brill(ql, qg, dens_l, dens_g, visc_l, visc_g, theta, step_length);   % [Pa]
        
    pRiser_Flow(i) = pRiser_Flow(i+1) + dpds/bara;
end


n_steps_m = zeros(1, nManifold);  % Steps from PLEM to Manifold
for j = 1:nManifold
    n_steps_m(j) = l_PLEM_WH(j)/step_length;   % For tubing
end
pPLEM_WH = zeros(  max(n_steps_m)+1, nManifold);
pPLEM_WH(end, :) = pRiser_Flow(1, :);

for r = 1:nManifold     % "r" is a new variabel so not to disturb "j" from the tubing-section.
    
    % To keep track of which wells are calculated:
    temp_10=0;
    for y = 1:r
        temp_9 = temp_10;
        temp_10 = temp_10+wells_in_manifold(y);
    end
    
    for i = ( max(n_steps_m) ):-1: ( max(n_steps_m) - n_steps_m(r)+1   )
        
        if count_2>0 % I.e. there has already been calculated at least one well with GL, and another is in progress.
            sum_gl_sc = 0;
            for k = 1:count_2
                if position_s(count_2)<=temp_10 && position_s(count_2)>temp_9  % I.e. other wells in the same manifold have been produced with GL previously.
                    sum_gl_sc = sum_gl_sc + qgl_sc(position_count1(count_2)  , position_s(count_2) ) + qgl_sc(count_1, s);
                end
            end
        else
                sum_gl_sc = sum(qgl_sc(count_1, :));   % I.e. sum of GL rate for all wells in that row. Only GL in max one well.
        end
        
        
        if size_oil(1)>1 % I.e. at least one well is calculated with reduced oil rate.
            sum_qo_sc = 0;
            for k = (temp_9+1):temp_10
                nonzero_value = find(qo_sc(:, k) ~=0);
                correct_value = nonzero_value(end);
                sum_qo_sc = sum_qo_sc + qo_sc(correct_value, k);
            end
        else
            sum_qo_sc = sum(qo_sc(temp_9+1:temp_10));   % I.e. Original oil rates count.
        end
        
        
        
        
        [ql, qg, dens_l, dens_g, visc_l, visc_g] = local_properties(pPLEM_WH(i+1, r), T, sum_qo_sc, sum(qw_sc(temp_9+1:temp_10)), sum(qg_sc(temp_9+1:temp_10)), sum_gl_sc); % Local fluid rates and properties 
        
        theta = asind(h_PLEM_WH(r)/l_PLEM_WH(r));
    
        dpds = dpBeggs_Brill(ql, qg, dens_l, dens_g, visc_l, visc_g, theta, step_length);   % [Pa]
        
        pPLEM_WH(i, r) = pPLEM_WH(i+1, r) + dpds/bara;
    end
    
end

for i = 1:nManifold
    if pPLEM_WH(1, i)==0
        X = find (pPLEM_WH(:, i) == 0);
        pPLEM_WH_end(1, i) = pPLEM_WH( X(end)+1, i);
    else
        pPLEM_WH_end(1, i) = pPLEM_WH(1, i);
    end 
end

for i = 1:nManifold
    temp_10=0;
    for y = 1:i
        temp_9 = temp_10;
        temp_10 = temp_10+wells_in_manifold(y);
    end
    
    dp_choke(1, temp_9+1:temp_10) = pTubing_end (1, temp_9+1:temp_10) - pPLEM_WH_end(1, i);
end






if s>0
    
    if count_3>1  % I.e. reduced oil rate is being calculated.
        count_1 = 2;
        temp2 = count_3;
        deltaP(count_3, s) = dp_choke(s);
        if adjust>=1
            break;
        end
    else
    
    
deltaP(count_1, s) = dp_choke(s);
temp2 = count_1;
if count_4==3
    temp2 = temp2+1;
end
count_1 = count_1 + 1;
%         if deltaP(2, s)<0   % I.e. deltaP(q_gl_max) is too low/below zero.
%             count_3 = count_3 +1;
%         end

    end
else
    break;
    
    
    
end
end

if s>0
    count_2 = count_2+1;
    position_s(count_2) = s;   % The well number of the one being calculated with gas lift.
    position_count1(count_2) = count_1-1;  % The position for the correct gas-lift rate.
end


disp(dp_choke);


if (dp_choke+0.1)>=0   % 0.1 is the error margin. If dpChoke>0 then no GL.
    break;
else
    count_1 = 2;
    count_3 = 1;  % If q_gl_max isn't enough, this number is initiated.
    count_4 = 0;  % Initiated if lower GL rates are tested.
    count_5 = 0;  % Initiated if spline has troubles with reduced oil rates.
    adjust = 0;
    reduced_oil_rate = false;
    optimal_oil_rate = false;
    
    s = find(  pTubing_end(:) == min(pTubing_end  (:)));   % S equals the well with the lowest pressure at WH.
    if length(s)>1
        s = s(1);    % If multiple wells have equal lowst pressure at WH, start with first one.
    end
    deltaP(1, s) = dp_choke(s);
    if count_2>=nWells && strcmp(str, 'ape')
        disp(dp_choke)
        fprintf('\n\n Warning: All wells have been injected with GL. Long flowlines and short riser may create an endless increase in injection.\n')
        prompt = 'Terminate? (y/n)';
        str = input(prompt,'s');
    end
end

if str == 'y'
    break;
end

end





%% Tidy-up section

% Pressures in the pipes:
p = zeros( (length(pTubing(:, 1))+length(pPLEM_WH(:, 1))+length(pRiser_Flow(:, 1)))-1, nWells);
p(1:length(pTubing), :) = pTubing;

for i = 1:nManifold
    temp_10=0;
    for y = 1:i
        temp_9 = temp_10;
        temp_10 = temp_10+wells_in_manifold(y);
    end
    for a = temp_9+1:temp_10
        p( (length(pTubing(:, 1))+1):(length(pTubing(:, 1))+length(pPLEM_WH(:, 1))) , a) = pPLEM_WH(:, i);
    end
    
end

for j =1:nWells
p ( (length(pTubing(:, 1))+length(pPLEM_WH(:, 1))):(length(pTubing(:, 1))+length(pPLEM_WH(:, 1))+length(pRiser_Flow(:, 1)))-1, j) = pRiser_Flow;
end

% GL rates:
for j =1:nWells
    temp = find(qgl_sc(:, j) ~= 0);
    if isempty(temp)
        qgl_sc_res(1, j) = 0;
    else
        qgl_sc_res(1, j) = qgl_sc(temp(end), j);
    end
end
qgl_sc_res = qgl_sc_res*day;

% Oil rates:
size_oil = size(qo_sc);
if size_oil(1)>1 % I.e. at least one well is calculated with reduced oil rate.
    qo_sc_res = zeros(1, nWells);
    for k = 1:nWells
        nonzero_value = find(qo_sc(:, k) ~=0);
        correct_value = nonzero_value(end);
        qo_sc_res(k) = qo_sc(correct_value, k)*day;
    end
else
    qo_sc_res = qo_sc*day;   % I.e. Original oil rates count.
end

fprintf('Calculated oil rates [Sm3/D]: \n\n');
format short g;
disp(qo_sc_res);
fprintf('Calculated GL rates [Sm3/D]: \n\n');
disp(qgl_sc_res);

end