function [pTubing, pPLEM_WH, pRiser_Flow, p, qo_sc_res, qg_sc, qw_sc, qgl_sc_res, dp_choke] = GL_sequential_NR(qo_sc, qw_sc, qg_sc, pR)

global TR pSep pBP_0 h_tubing l_tubing h_flowline l_flowline h_riser l_riser ...
        nWells bara day qgl_sc_max wc GOR_0 qo_sc_min l_PLEM_WH h_PLEM_WH ...
        nManifold wells_in_manifold step_length ID_t ID_f ID_m T_sc TVD
    

[pWf] = IPR_multi(qo_sc, pBP_0, pR);


qw_sc = qo_sc.*wc; 
qg_sc = qo_sc.*GOR_0; 
qo_sc_init = qo_sc;
fprintf('dp_choke [bar]: \n\n');
step_length = 10; % [m]

%% Pressure drop in tubing, from Bottom of Well to WH.
n_steps_t = zeros(1, nWells);
for j = 1:nWells
    n_steps_t(j) = l_tubing(j)/step_length;   % For tubing
    pTubing = zeros(n_steps_t(j)+1, nWells);
    TTubing = pTubing;
end



qgl_sc = zeros(1, nWells);
dp_choke = zeros(1, nWells);
s = 0;
start = true;
first_time_problem = true;
first_iteration = true;
reduce_init_rate = false;
reduction_trouble = false;
recalculate = false;
endless_loop_count = ones(1, nWells);

while s>=0
    if s ==0
        temp_1 = 1;
    else
        temp_1=s;
    end
while (abs(dp_choke (1, temp_1)) > 0.1) || start
    start = false;
for j = 1:nWells    
    
    if s>0  % "s" indicates the well that is currently being re-calculated because the pressure is too low.
        j = s;
        if qgl_sc(1, j) == 0 && optimal_oil_rate==false  % I.e. first iteration.
            
            dp_choke_old = dp_choke(s);
            qgl_sc_old = 0;
            qgl_sc(1, j) = qgl_sc_max;

        elseif dp_choke(1, j)<0 && qgl_sc_old == 0 && optimal_oil_rate==false   % I.e. deltaP(q_gl_max) is too low/below zero.

            if qgl_sc(1, j) > (qgl_sc_max*0.65^2) % I.e. 3 reduced GL rates
                qgl_sc(1, j) = qgl_sc(1, j)*0.65;
            else
                % Reduce to oil rate until a valid rate is found (dp_choke>0 with qgl_sc_max):
                    
                    qo_sc_old = qo_sc(j);
                    qgl_sc(1, j) = qgl_sc_max;
                    qo_sc(1, j) = qo_sc(1, j)*(0.9^(endless_loop_count(s))); % This re-calculates the first deltaP for no GL and lower oil rate.
                    [pWf(1, j)] = IPR_multi(qo_sc(1, j), pBP_0, pR);
                    qw_sc(j) = qo_sc(1, j).*wc(j);
                    qg_sc(j) = qo_sc(1, j).*GOR_0;

                if qo_sc(1, j)< qo_sc_min || pWf(j)<pSep
                    reduce_init_rate = true;
                    reduce_init_well = j;
                    s = 0;
%                     qgl_sc = 0;
%                     qo_sc_init = qo_sc_init*0.99;
%                     qo_sc = qo_sc_init;
                    fprintf('Error: pR is too low for well %d to be produced. \n Probable reason is that initial rates in all wells are too high. Rates reduced with 5%%. \n', j);
                    break;
                end

                    reduced_oil_rate = true;
                    first_valid_value = true;
            end
            
            
        else
            
            if reduced_oil_rate  % Solver has found a reduced oil rate that gives positive dp_choke. qgl_sc is now kept the same.
                if first_valid_value  % Solver has found the first valid reduced oil rate. This is the first iteration. Because it's uncertain what the valid GL rate is, previous dp_choke's are uncertain. This is calculated now.
                    qgl_sc_old = -1;  % Make the old value of zero invalid
                    temp_1 = qo_sc(j); % This is the lower boundary for the oil rate.
                    qo_sc(j) = qo_sc_init(j); %   % Slacker bounds give more stable converging, but also risk the rate being lowered too much (lower bound slack) and the runtime to increase (upper bound slack)          This is the upper boundary for the oil rate = lower_boundary/0.9
                    qo_sc_old = temp_1;
                    dp_choke_old = dp_choke(j); % Newly calculated, positive value.
                    count_rate = 0;
                    first_valid_value = false;
                else
                    count_rate = count_rate+1;
                    if count_rate>20
                        fprintf('The solver has an issue with converging the oil rate for well %d \n\n', s);
                        
                        endless_loop_count(s) = endless_loop_count(s) + 1;
                        
                        reduction_trouble = true;
                        break;
                    end
                    temp_1 = qo_sc(1, j);
                    qo_sc(j) = qo_sc (j) - dp_choke(j)/(dp_choke(j)-dp_choke_old)*(qo_sc(j)-qo_sc_old);
                    
                    qo_sc_old = temp_1;
                    dp_choke_old = dp_choke(j);
                end
                    [pWf(1, j)] = IPR_multi(qo_sc(1, j), pBP_0, pR);
                    qw_sc(j) = qo_sc(1, j).*wc(j);
                    qg_sc(j) = qo_sc(1, j).*GOR_0;
                    
                
                
            else
            
            temp_1 = qgl_sc(1, j);
            
            qgl_sc(1, j) = qgl_sc(1, j) - dp_choke(1, j)/(dp_choke(1, j)-dp_choke_old)*(qgl_sc(1, j)-qgl_sc_old);    % x = x -f(x)/f'(x)
            
            dp_choke_old = dp_choke(1, j);
            qgl_sc_old = temp_1;
            
            end

        end
    elseif recalculate
        s = s2;
        j = s;
    end
    
    theta = asind(h_tubing(j)/l_tubing(j));   % Inclination in degrees from horizontal.
    pTubing (1, j) = pWf(j);
    TTubing(1, j) = TR;
    ge = (T_sc-TR)/TVD(j);  % Geothermal gradient
%     U0 = 4; % Don't know the value
%     U = 1/ID_t/2 *U0;  % Heat transfer coefficient
    
%         if pTubing(1, j)<pSep
%             reduce_init_rate = true;
%             reduce_init_well = j;
%             break;
%         end

    for i = 1:n_steps_t(j)    
        
        
         
         
         [ql, qg, dens_l, dens_g, visc_l, visc_g, SIG, gamma_g, gamma_l] = local_properties(pTubing(i, j), TTubing(i, j), qo_sc(j), qw_sc(j), qg_sc(j), qgl_sc(j)); % Local fluid rates and properties 

         if i == 1
             vm_old = (ql+qg)/(pi * (ID_t/2)^2);
         else
             vm_old = vm;
         end
         vm = (ql+qg)/(pi * (ID_t/2)^2);
         
         dvds = (vm-vm_old)/step_length;
          [dpds, rho_m, holdup] = multi_dpdx(ql, qg, dens_l, dens_g, visc_l, visc_g, theta, ID_t, SIG);   % [Pa]
        % Rho_m is with slip (check formulas if this is true)
          pTubing(i+1, j) = pTubing(i, j) - dpds/bara*step_length;
          TTubing(i+1, j) =  TR;
         [Cpg, Cpo] = HeatCapacity(gamma_g, gamma_l, TTubing(i, j));
         Cp = (dens_l*ql*Cpo + dens_g*qg*Cpg)/(dens_l*ql+dens_g*qg);
         % Calculation of relaxation distance (Ramsey 1962)
         A = (dens_l*ql+dens_g*qg)*Cp/(U*pi*ID_t);
         rho_ns = ql/(ql+qg)*dens_l + qg/(qg+ql)*dens_g;
         TTubing (i+1, j) = multi_dTdx(TTubing(i, j), pTubing(i+1, j), theta, rho_m, rho_ns, ge, Cp, holdup, dpds, dvds, A, gamma_g, vm);
         
         
    end
   
    if sum( imag(pTubing(:, j)) )~=0||pTubing(i, j)<pSep
        reduce_init_rate = true;
        reduce_init_well = j;
        pTubing(:, j) = real(pTubing(:, j));  % If pTubing goes below zero, imaginary numbers will be generated.
        break;
    end
    
   if s>0  % Only calculate lowest well.
       break;
   end
    
end

if reduce_init_rate == false;
if reduction_trouble
    reduction_trouble = false;
    break;
end
% Find final nonzero element in tubing (pWh)
for i = 1:nWells
    if pTubing(end, i)==0
        X = find (pTubing(:, i) == 0);
        pTubing_end(i) = pTubing( X(1)-1, i);
    else
        pTubing_end(i) = pTubing(end, i);
    end
    
    
end





%% Pressure drop in riser and flowline, from Sep to PLEM.
n_steps_f = (l_riser+l_flowline)/step_length;

pRiser_Flow = zeros(n_steps_f+1, 1);
pRiser_Flow (end) = pSep;
T = TR;  % Should be made into a function.

for i = (n_steps_f):-1:1
    
    
    
    [ql, qg, dens_l, dens_g, visc_l, visc_g] = local_properties(pRiser_Flow(i+1), T, sum(qo_sc), sum(qw_sc), sum(qg_sc), sum(qgl_sc)); % Local fluid rates and properties 

    if i<=l_flowline/step_length  % I.e. is the calculation in the flowline or in the riser
        theta = asind(h_flowline/l_flowline);
    else
        theta = asind(h_riser/l_riser);
    end    
    dpds = dpBeggs_Brill(ql, qg, dens_l, dens_g, visc_l, visc_g, theta, step_length, ID_f);   % [Pa]
        
    pRiser_Flow(i) = pRiser_Flow(i+1) + dpds/bara;
end


n_steps_m = zeros(1, nManifold);  % Steps from PLEM to Manifold
for j = 1:nManifold
    n_steps_m(j) = l_PLEM_WH(j)/step_length;   % For tubing
end
pPLEM_WH = zeros(  max(n_steps_m)+1, nManifold);
pPLEM_WH(end, :) = pRiser_Flow(1, :);



for r = 1: nManifold   % "r" is a new variabel so not to disturb "j" from the tubing-section.
    
    % To keep track of which wells are calculated:
    temp_10=0;
    for y = 1:r
        temp_9 = temp_10;
        temp_10 = temp_10+wells_in_manifold(y);
    end
    
    for i = ( max(n_steps_m) ):-1: ( max(n_steps_m) - n_steps_m(r)+1   )
        

        
        
        [ql, qg, dens_l, dens_g, visc_l, visc_g] = local_properties(pPLEM_WH(i+1, r), T, sum(qo_sc(temp_9+1:temp_10)), sum(qw_sc(temp_9+1:temp_10)), sum(qg_sc(temp_9+1:temp_10)), sum(qgl_sc(temp_9+1:temp_10))); % Local fluid rates and properties 
        
        theta = asind(h_PLEM_WH(r)/l_PLEM_WH(r));
    
        dpds = dpBeggs_Brill(ql, qg, dens_l, dens_g, visc_l, visc_g, theta, step_length, ID_m(r));   % [Pa]
        
        pPLEM_WH(i, r) = pPLEM_WH(i+1, r) + dpds/bara;
    end
    
end

for i = 1:nManifold
    if pPLEM_WH(1, i)==0
        X = find (pPLEM_WH(:, i) == 0);
        pPLEM_WH_end(1, i) = pPLEM_WH( X(end)+1, i);
    else
        pPLEM_WH_end(1, i) = pPLEM_WH(1, i);
    end 
end

for i = 1:nManifold
    temp_10=0;
    for y = 1:i
        temp_9 = temp_10;
        temp_10 = temp_10+wells_in_manifold(y);
    end
    
    dp_choke(1, temp_9+1:temp_10) = pTubing_end (1, temp_9+1:temp_10) - pPLEM_WH_end(1, i);
end


end

if s>0
    if recalculate
        recalculate = false;
        qgl_sc_old = -1;
        if dp_choke(s)>0 % Recalculated well with positive choke, initial rates and no GL
            break;
        end
    end
    temp_1 = s;
else
    break;
end
    
    
    
end


if s>0
    if endless_loop_count(s)==10
        fprintf('Program run into an endless loop of re-iteration for well %d. Program stops and returns values close to target. \n\n', s);
       break;
    end
end


disp(dp_choke);
    if isnan(sum(dp_choke))||reduce_init_rate % Imaginary numbers due to high oil rate
        reduce_init_rate = false;
        s = 0;
        %qgl_sc(1, 1:nWells) = qgl_sc_max;
        start = true;
        if qo_sc_init(reduce_init_well)== 0
            qgl_sc(reduce_init_well) = qgl_sc_max;
        else
            qo_sc_init(reduce_init_well) = qo_sc_init(reduce_init_well)*0.9;
        end
        
        qo_sc = qo_sc_init;
        [pWf] = IPR_multi(qo_sc, pBP_0, pR);
        qw_sc = qo_sc.*wc;
        qg_sc = qo_sc.*GOR_0;
        %fprintf('Error: Too high rates in some of the wells result in NaN. All rates reduced by 1%%. \n');
    elseif first_iteration
        first_iteration = false;
        if dp_choke<0 % For all wells
            qgl_sc (1, 1:nWells) = qgl_sc_max;
        end
    else

        

if (dp_choke+0.1)>=0   % 0.1 is the error margin. If dpChoke>0 then no GL.
    count = [];
    for i = 1:nWells
        if dp_choke(i)>0.1
            if (qgl_sc(i)>0 || qo_sc(i)<qo_sc_init(i)-10^(-10))
                count = [count i];
            end
        end
    end
    
    if isempty(count)
        break;
    else
        reduced_oil_rate = false;
        optimal_oil_rate = false;
    
        s = find(  dp_choke(:) == max(dp_choke  (count)));   % S equals the well with the lowest pressure at WH.
        if length(s)>1
            s = s(1);    % If multiple wells have equal lowst pressure at WH, start with first one.
        end
        qgl_sc_old = -1;  % Wrong value to get the solver started.
        qgl_sc(s) = 0; % Calculations starting with reduced rates.
        qo_sc(s) = qo_sc_init(s);
        [pWf(1, s)] = IPR_multi(qo_sc(1, s), pBP_0, pR);
        qw_sc(s) = qo_sc(1, s).*wc(s);
        qg_sc(s) = qo_sc(1, s).*GOR_0;
        s2 = s;
        s = 0;
        recalculate = true;
        start = true;
    end
else
    reduced_oil_rate = false;
    optimal_oil_rate = false;
    
    s = find(  dp_choke(:) == min(dp_choke  (:)));   % S equals the well with the lowest pressure at WH.
    if length(s)>1
        s = s(1);    % If multiple wells have equal lowst pressure at WH, start with first one.
    end
        qgl_sc_old = -1;  % Wrong value to get the solver started.
        if qgl_sc(s)>0 % I.e. re-calculation of GL-rate
            qgl_sc(s) = 0; % Calculations starting with reduced rates.
            qo_sc(s) = qo_sc_init(s);
            [pWf(1, s)] = IPR_multi(qo_sc(1, s), pBP_0, pR);
            qw_sc(s) = qo_sc(1, s).*wc(s);
            qg_sc(s) = qo_sc(1, s).*GOR_0;
            s2 = s;
            s = 0;
            recalculate = true;
            start = true;
        end
end

if  s>0 % The previous calculation resultet in infeasible solution (close to correct solution), but will continue in an endless loop. This answer is anyway close to the solution.
    if endless_loop_count(s)==1
        endless_loop_count(:) = 1;
    end

end
    end

end





%% Tidy-up section

% Pressures in the pipes:
p = zeros( (length(pTubing(:, 1))+length(pPLEM_WH(:, 1))+length(pRiser_Flow(:, 1)))-1, nWells);
p(1:length(pTubing), :) = pTubing;

for i = 1:nManifold
    temp_10=0;
    for y = 1:i
        temp_9 = temp_10;
        temp_10 = temp_10+wells_in_manifold(y);
    end
    for a = temp_9+1:temp_10
        p( (length(pTubing(:, 1))+1):(length(pTubing(:, 1))+length(pPLEM_WH(:, 1))) , a) = pPLEM_WH(:, i);
    end
    
end

for j =1:nWells
p ( (length(pTubing(:, 1))+length(pPLEM_WH(:, 1))):(length(pTubing(:, 1))+length(pPLEM_WH(:, 1))+length(pRiser_Flow(:, 1)))-1, j) = pRiser_Flow;
end

% GL rates:
for j =1:nWells
    temp = find(qgl_sc(:, j) ~= 0);
    if isempty(temp)
        qgl_sc_res(1, j) = 0;
    else
        qgl_sc_res(1, j) = qgl_sc(temp(end), j);
    end
end
qgl_sc_res = qgl_sc_res*day;

% Oil rates:
size_oil = size(qo_sc);
if size_oil(1)>1 % I.e. at least one well is calculated with reduced oil rate.
    qo_sc_res = zeros(1, nWells);
    for k = 1:nWells
        nonzero_value = find(qo_sc(:, k) ~=0);
        correct_value = nonzero_value(end);
        qo_sc_res(k) = qo_sc(correct_value, k)*day;
    end
else
    qo_sc_res = qo_sc*day;   % I.e. Original oil rates count.
end

fprintf('Calculated oil rates [Sm3/D]: \n\n');
format short g;
disp(qo_sc_res);
fprintf('Calculated GL rates [Sm3/D]: \n\n');
disp(qgl_sc_res);

end