function [ql, qg, dens_l, dens_g, visc_l, visc_g, SIG, gamma_g, Cp] = local_properties(p, T, qo_sc, qw_sc, qg_sc, qgl_sc)

global gamma_g_0 gamma_gl_0 visc_g_sc_0 GOR_0 R dens_o_sc dens_w_sc p_sc T_sc M_air bara

if qgl_sc~=0
    qg_tot_sc = qg_sc + qgl_sc;
    GOR = qg_tot_sc/qo_sc;
    gamma_g = (qg_sc*gamma_g_0 + qgl_sc*gamma_gl_0)/(qg_tot_sc);
    pBP = bubble_point(GOR, T, gamma_g);
    visc_g_sc = dead_visc_gas(gamma_g);
else  % No GL
    qg_tot_sc = qg_sc;
    GOR = GOR_0;
    gamma_g = gamma_g_0;
    pBP = bubble_point(GOR, T, gamma_g);
    visc_g_sc = visc_g_sc_0;  
end
Rs = solution_GOR(p, T, gamma_g, pBP);
[z, Ppr, Tpr] = z_Standing(p, T, gamma_g);
dens_g_sc = gamma_g*M_air*p_sc*bara/(R*T_sc);
[Bo, Bw, Bg] = FVF (gamma_g, Rs, p, T, z, pBP);

qg =(qg_tot_sc-Rs*qo_sc)*Bg;
if qg<0
    qg = 0;
end
qo = qo_sc*Bo + Rs * qo_sc*Bg;
qw = qw_sc*Bw;
ql = qo+qw;

dens_o = (dens_o_sc+dens_g_sc*Rs)/Bo;
dens_g = dens_g_sc/Bg;
dens_w = dens_w_sc/Bw;
dens_l = (dens_w*qw + dens_o*qo)/ql;

gamma_l = (dens_o_sc*qo + dens_w_sc*qw)/(ql*dens_w_sc);

% [cp]
visc_o = oil_visc_standing(p, T, Rs, pBP);
%visc_w = water_visc2(T);
if T<273.15
    visc_w = visc_o;
else
    visc_w = XSteam('my_pT', p, T-273.15)*1000;
end
visc_g = gas_visc(Ppr, Tpr, visc_g_sc);

% TODO: Find better correlation for mixture viscosity.
% wc_cuttoff = 0.6;
% wc = (qw/ql);
% if wc > wc_cuttoff
%     expw = 3.089;
%     visc_l = visc_w*exp(expw*(1-wc));
% else
%     expo = 3.215;
%     visc_l = visc_o*exp(expo*(wc));
% end

% http://people.clarkson.edu/~wwilcox/Design/HYSYSpropSelect.pdf

if qo/ql>=0.5
    visc_l = visc_o*exp(3.6*(1-qo/ql));
elseif qo/ql<=0.33
    visc_l = (1+2.5*qo/ql*(visc_o+0.4*visc_w)/(visc_o+visc_w))*visc_w;
else
    visc_weighted1 = visc_o*exp(3.6*(1-qo/ql));
    visc_weighted2 = (1+2.5*qo/ql*(visc_o+0.4*visc_w)/(visc_o+visc_w))*visc_w;
    visc_l = ((qo/ql-0.33)*visc_weighted1 + (0.5-qo/ql)*visc_weighted2)/(0.5-0.33);
end

% Surface tensions:

fw = qw/qo;

% Gas surface tension(?)
SIG = (STog(dens_o, dens_g) * 0.001 * (fw + 1)) + (fw * 0.001 * STwg(T));

%% Calculation of Cp

[Cpo, Cpg] = HeatCapacity(gamma_g, T);
if T<273.15
    Cpw = Cpo;
else
    Cpw = XSteam('Cp_pT', p, T-273.15)*1000;
end
%Cp = (dens_o*qo*Cpo + dens_w*qw*Cpw + dens_g*qg*Cpg)/(dens_l*ql+dens_g*qg);
Cp = 2000;
        
end