function [res, A] = multi_dTdx_tubing_simple(T1, p, theta, rho_m, rho_ns, ge, Cp, holdup, dpds, dvds, Wt, gamma_g, vm, T_amb)

global ro_t k_steel step_length ID_t

%% Calculation of the Joule Thomson Coefficient
% T1 is inlet fluid temperature.
z1 = z_Standing(p, T1, gamma_g);
z2 = z_Standing(p, T1+0.1, gamma_g);
dzdT = (z2-z1)/0.1;
eta = -1/(Cp*rho_ns)* ((1-holdup)*(-T1/z1*dzdT) + holdup);

% Calculation of the dimensionless parameter (Ramsey 1962)

fi = (rho_m *eta*Cp*dpds - rho_m*9.81*sind(theta)-rho_m*vm*dvds)/dpds;

%% Calculation of the Heat Transfer 
Layerinfoeach (1) = ID_t/2 * 3.2808399; % Tubing inner radius[Feet]; % Default
Layerinfoeach (2) = ro_t*3.2808399; % Tubing outer radius[Feet]
Layerinfoeach (3) = k_steel/1.7; % Tubing wall conductivity [Btu/hr ft F]
Layerinfoeach (4) = Layerinfoeach (2)+4/12; % Outer radius of Annulus (Casing inner diameter) (4") [Feet]
Layerinfoeach (5) = 0.383; % Annulus conductivity [Btu/hr ft F]
Layerinfoeach (6) = 1; % Annular fluid Heat Capacity [Btu/lbm F]
Layerinfoeach (7) = 1; % Annular fluid Viscosity [cp]
Layerinfoeach (8) = 62.373; % Annular fluid density [lbm/ft^3]
Layerinfoeach (9) = Layerinfoeach (4) + 0.8/12; % Casing outer radius (0.8") [Feet]
Layerinfoeach (10) = 21; % Casing conductivity [Btu/hr ft F]
Layerinfoeach (11) = Layerinfoeach (9) + 2/12; % Cement outer radius (r well bore) (2") [Feet]
Layerinfoeach (12) = 4.021; % Cement conductivity [Btu/hr ft F]

kearth = 0.83; % [Btu/hr ft F]
Difearth = 0.04; % [ft^2/hr]
prodtime = 164.0; % [Hr]
td1each = TempD(Td(Difearth, prodtime, Layerinfoeach(11)));

HTC = HTC_calc(Layerinfoeach (1), Layerinfoeach (2), Layerinfoeach (4), ...
        Layerinfoeach (5), Layerinfoeach (11), Layerinfoeach (9), Layerinfoeach (12) );


%% Calculation of the Temperature
     A = Acalc(Cp, Wt, kearth, Layerinfoeach(1, 1), HTC, td1each);    
    
    res = T_amb - ge*step_length*sind(theta) + (T1-T_amb)*exp(-step_length/A) ...
        + ge*A*sind(theta)*(1-exp(-step_length/A)) + dpds*fi*A*(1-exp(-step_length/A))/(Cp*rho_m);




end