function [Fv]=test(T, P)

%global dens_o_sc dens_w_sc

NRerror = 1e-2;         % Newton-Rhapson error tolerance
e = 1e-2;               % Fugacity convergence tolerance

% Pl = 37;                % Lower pressure limit [bar]
% Pu = 100;               % Upper pressure limit [bar]
% dP = 1;                 % Delta pressure [bar]


%for P=Pl:dP:Pu;          % [bar]
    



frr=1;                               % Avtivate the fugacity while-loop

R = 8.314E-5;                           % Gas constant
FluidProp = xlsread ( 'FluidProp' );    % Fluid properties
Pci = FluidProp(:,4);                   % Critical pressure [bar]
Tci = FluidProp(:,5);                   % Critical temperature [K]
Vci = FluidProp(:,6);                   % Critical volume [m3/kmol]
kij = xlsread ( 'PR-EOS-BIPS' );        % BIP's
kij= kij + kij';
z = FluidProp(:,1);                     % Mixture composition
Mi = FluidProp(:,2);                    % Molar weight kg/kmol
AF = FluidProp(:,8);                    % Acentric factor
VTP = FluidProp(:,11);                  % PR Volume translation parameters

% MolarFlowTot = MolarFlow + MolarFlowGL; % Now including GL
% 
% z = (z*MolarFlow + y_GL*MolarFlowGL)/MolarFlowTot; % New composition due to GL


%% K Value estimate; Wilson equation

Pri = P ./ Pci;                       % Reduced pressure
Tri = T ./ Tci;                       % Reduced temperature



K = exp(5.37 * (1 + AF) .* (1 - 1 ./ Tri)) ./ Pri ;   % Phase equilibrium factor

m = zeros(length(z), 1);
for j = 1 : length(z)
    
    if AF(j) < 0.4
        
        m(j) = 0.37464 + 1.54226 * AF(j) - 0.26992 * AF(j)^2;
        
    else
        
        m(j) = 0.3796 + 1.485 * AF(j) - 0.1644 * AF(j)^2 + 0.01667 * AF(j)^3;

    end
end

alfa = (1 + m .* (1 - sqrt(Tri))).^2;

a = 0.45724 * R^2 * Tci.^2 ./ Pci .* alfa;

b = 0.07780 * R * Tci ./ Pci;

A = a * P / (R * T)^2;

B = b * P / (R * T);

%% Fv calculation; Rachford-Rice 

while frr>e      %Fugacity tolerance constraint
    
    
Fvmin = 1 / (1 - max(K));
Fvmax = 1 / (1 - min(K));


%syms Fv        % Matlab numerical solver
%Fv=double(vpasolve(sum(z .* (K - 1) ./ (1 + Fv(1) * (K - 1))),Fv,[Fvmin Fvmax]));


% Newton-Raphson method
Fv(1) = (Fvmin+Fvmax)/2;            % Initial guess
    
hFv = sum(z .* (K - 1) ./ (1 + Fv(1) * (K - 1)));

dhFv = - sum(z .* (K - 1).^2 ./ (Fv(1) * (K - 1) + 1).^2);

Fv(2) = Fv(1) - hFv / dhFv;

while abs(Fv(1) - Fv(2)) > NRerror     % Error tolerance
    
    Fv(1) = Fv (2);
    
    hFv = sum(z .* (K - 1) ./ (1 + Fv(1) * (K - 1)));

    dhFv = - sum(z .* (K - 1).^2 ./ (Fv(1) * (K - 1) + 1).^2);

    Fv(2) = Fv(1) - hFv / dhFv;
    
end


if Fv(2) > Fvmin && Fv(2) < Fvmax
    Fv = Fv(2);
end

% Liquid and vapor phase composition

x = z ./ (Fv .* (K - 1) + 1);

y = K .* x;


%% A / B parameters

Aij = (1-kij) .* sqrt(A * A');

AL = x' * Aij * x;

AV = y' * Aij * y;

BV = y' * B;

BL = x' * B;

syms Zl Zv

Zl = real(double(solve(Zl^3 - (1 - BL)*Zl^2 + (AL -3*BL^2-2*BL)*Zl-(AL*BL-BL^2-BL^3))));

Zl = Zl(1);


Zv = real(double(solve(Zv^3 - (1 - BV)*Zv^2 + (AV -3*BV^2-2*BV)*Zv-(AV*BV-BV^2-BV^3))));

Zv = Zv(1);


%% Fugacity

% Liquid fugacity
fl = exp(B/BL*(Zl-1)-log(Zl-BL)+AL/(2*sqrt(2)*BL)*(B/BL-2/AL*Aij*x)*log((Zl+(1+sqrt(2))*BL)/(Zl+(1-sqrt(2))*BL))+log(x*P));

% Vapor fugacity
fv = exp(B/BV*(Zv-1)-log(Zv-BV)+AV/(2*sqrt(2)*BV)*(B/BV-2/AV*Aij*y)*log((Zv+(1+sqrt(2))*BV)/(Zv+(1-sqrt(2))*BV))+log(y*P));

% Fugacity ratio
fr=fl./fv;

% K value update
K=K.*fr;

% Convergence test
frr=sum((1-fr).^2);
end



% Fv<0 => Single phase, liquid

if Fv<0
    
    Fv = 0;
    x=z;
    y=zeros(length(z),1);
    
    
% Fv>1 => Single phase, vapor
    
elseif Fv>1;
    
    Fv = 1;
    y=z;
    x=zeros(length(z),1);
    
end

% Save Fv for every pressure calculation in a vector
% Fvv=Fv;

%% Vapor properties


Mv = Mi'*y;                                      % Vapor phase molar weight

%GasDensityEOS = P * Mv*1E-3 / (Zv * R * T);   % EOS calculated vapor density
vvEOS = Zv * R * T* 1E+3/P;                      % EOS calculated vapor molar volume

c = b*1E3 .* VTP;                                   % Volume translation parameter

vvCOR = vvEOS - sum(c.*y);                    % Corrected vapor molar volume
GasDensity = Mv / vvCOR;                % Corrected vapor density



%% Liquid properties

Ml = Mi'*x;                                      % Liquid phase molar weight

vlEOS = Zl * R * T* 1E+3/P;                      % Liquid phase molar volume

c = b*1E3 .* VTP;                                   % Volume translation parameter

vlCOR = vlEOS - sum(c.*x);                    % Corrected liquid phase molar volume


%OilDensityEOS = P * Ml*1E-3 / (Zl * R * T);   % EOS calculated liquid density
OilDensity = Ml / vlCOR;                % Corrected liquid density

% WaterDensity = XSteam('rho_pT', p, T-273.15);
% 
% GasMassFlow = MolarFlowTot*Mv; % Kg/s
% OilMassFlow = MolarFlowTot*Ml; % Kg/s
% 
% qg = GasMassFlow/GasDensity; % m3/s
% qo = OilMassFlow/OilDensity; % m3/s
% qw = wc*qo/(1-wc);
% ql = qo+qw;
% 
% LiquidDensity = (WaterDensity*qw + OilDensity*qo)/ql;
% gamma_g = Mv/28.97;
% gamma_l = (dens_o_sc*qo + dens_w_sc*qw)/(ql*dens_w_sc);
% 
% %% Viscosities
% a0 = 0.1023;
% a1 = 0.023364;
% a2 = 0.058533;
% a3 = -0.040758;
% a4 = 0.0093324;
% 
% % Units should be in: cp, Atm, K.
% Pci = Pci*0.986923267;
% 
% 
% mu_i = zeros(length(z), 1);
% for i =1:length(z)
%     xi_Ti = (Tci(i)*Mi(i)^3/Pci(i)^4)^(1/6);
%     if Tri(i)<=1.5
%         mu_i(i) = 34*10^(-5)*Tri(i)^0.94/xi_Ti;
%     else
%         mu_i(i) = 17.78*10^(-5)*(4.58*Tri(i)-1.67)^(5/8)/xi_Ti;
%     end
% end
% 
% % Gas:
% if sum(y)>0
% % Tpc_v = sum(Tci.*y);
% % Ppc_v = sum(Pci.*y);
% % Vpc_v = sum(Vci.*y);
% % 
% % mu_0_v = sum(mu_i.*y.*sqrt(Mi))/(sum(y.*sqrt(Mi)));
% % 
% % xi_Tv = (Tpc_v/(Mv^3*Ppc_v^4))^(1/6);
% % rho_prv = GasDensity/Mv*Vpc_v;
% %mu_v = ((a0 + rho_prv*a1 + rho_prv^2*a2 + rho_prv^3*a3 + rho_prv^4*a4)^4-10^(-4))/xi_Tv + mu_0_v;
% visc_v = lee_gonzalez(GasDensity, T, Mv);
% else
%     visc_v = 0;
% %    mu_v2 = 0;
% end
% 
% % Liquid:
% if sum(x)>0
% Tpc_l = sum(Tci.*x);
% Ppc_l = sum(Pci.*x);
% Vpc_l = sum(Vci.*x);
% 
% mu_0_l = sum(mu_i.*x.*sqrt(Mi))/(sum(x.*sqrt(Mi)));
% 
% xi_Tl = (Tpc_l/(Ml^3*Ppc_l^4))^(1/6);
% rho_prl = OilDensity/Ml*Vpc_l;
% visc_o = ((a0 + rho_prl*a1 + rho_prl^2*a2 + rho_prl^3*a3 + rho_prl^4*a4)^4-10^(-4))/xi_Tl + mu_0_l;
% else
%     visc_o = 0;
% end
% 
% visc_w = XSteam('my_pT', p, T-273.15)*1000;
% 
% if qo/ql>=0.5
%     visc_l = visc_o*exp(3.6*(1-qo/ql));
% elseif qo/ql<=0.33
%     visc_l = (1+2.5*qo/ql*(visc_o+0.4*visc_w)/(visc_o+visc_w))*visc_w;
% else
%     visc_weighted1 = visc_o*exp(3.6*(1-qo/ql));
%     visc_weighted2 = (1+2.5*qo/ql*(visc_o+0.4*visc_w)/(visc_o+visc_w))*visc_w;
%     visc_l = ((qo/ql-0.33)*visc_weighted1 + (0.5-qo/ql)*visc_weighted2)/(0.5-0.33);
% end
% 
% SIG_sum = 0;
% for i =1:length(z)
%     if Mi(i)>90 % I.e. C7+
%         Parachor = 35 + 2.4*Mi(i);
%     else
%         Parachor = 25.3 + 2.86*Mi(i);
%     end
%     if sum(y)==0
%         SIG_sum = SIG_sum + Parachor*(x(i)*OilDensity/Ml)/1000;
%     elseif sum(x)==0
%         SIG_sum = SIG_sum + Parachor*(y(i)*GasDensity/Mv)/1000;
%     else
%         SIG_sum = SIG_sum + Parachor*(x(i)*OilDensity/Ml - y(i)*GasDensity/Mv)/1000;
%     end
% end
% SIG = SIG_sum^4;
% 
% %% Calculation of Cp
% Cpw = XSteam('Cp_pT', p, T-273.15)*1000;
% [Cpg, Cpo] = HeatCapacity(gamma_g, gamma_l, T);
% Cp = (OilDensity*qo*Cpo + WaterDensity*qw*Cpw + GasDensity*qg*Cpg)/(LiquidDensity*ql+GasDensity*qg);
% 
% 
% end
% 
% %figure(1)
% %plot(Pl:dP:Pu,Fvv*100)
% %xlabel('pressure [bar]')
% %ylabel('vapor mole fraction [%]')
% 
% %figure(2)
% %hold on
% %plot(Pl:dP:Pu,OilDensityEOS,'r')
% %plot(Pl:dP:Pu,OilDensityCOR)
% %hold off
% 
% %figure(3)
% %hold on
% %plot(plot(Pl:dP:Pl+dP*(sum(Fvv>0)-1),GasDensityCOR(1:sum(Fvv>0))),'r')
% %plot(plot(Pl:dP:Pl+dP*(sum(Fvv>0)-1),GasDensityEOS(1:sum(Fvv>0))))
% %hold off









